[![Build Status](https://travis-ci.com/axel-sirota/ci-cd-with-travis.svg?branch=master)](https://travis-ci.com/axel-sirota/ci-cd-with-travis)

Sample Flask app for Getting Started with Travis CI Course at Pluralsight

This app is a simple nlp-based question-answering with web interface, based on https://sweetcode.io/flask-app-github-travis-heroku/, and extended on the travis side to test in parallel multiple OS, multiple versions and have multiple types of deployment.

For each module in the course just run `git checkout MODULE{MODULE_NUMBER}-DEMO{DEMO_NUMBER}`, for example, `git checkout module4-demo1`, and you will be at the point of the recording.

For any question, don't hesitate to leave an issue here, send me an email (axel.sirota@gmail.com) or tweet me (@AxelSirota)!
